;; Generated package description from mode: lisp-data; .el  -*- consult-denoteno-byte-compile: t -*-
(define-package "consult-denote" "0.3.0" "Use Consult in tandem with Denote" '((emacs "28.1") (denote "3.0.3") (consult "1.7")) :commit "62a1b64ebebb927bc204b87e61c4b1a1c576954e" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou" . "info@protesilaos.com") :url "https://github.com/protesilaos/consult-denote")
